<?php

namespace App\Http\Controllers\AccountManager;

use App\Http\Controllers\Controller;
use App\Models\AccountManagerLogs;
use App\Models\AdminLogs;
use App\Models\Client;
use App\Models\Group;
use App\Models\SubAccount;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class AccountManagerGroupController extends Controller
{
    // Add Group Form View
    public function index()
    {

        $clients = Client::where('deleted_at', null)->get();
        $subaccounts = SubAccount::where('deleted_at', null)->get();
        return view('accountmanager.group.add-group', compact('clients', 'subaccounts'));
    }


    // Group creation
    public function creategroup(Request $request)
    {

        $request->validate([
            'name' => 'required',
            'created_by'    =>    'required',
            'role_id'    =>    'required',
        ]);

        $data = $request->all();
        $check = $this->create($data);

        // Generate Log On Create Group
        $get_account_manager = (Auth::guard('account_manager')->user());
        $account_manager_register_log = AccountManagerLogs::create([

            'account_manager_id'      =>  $get_account_manager->id,
            'role_id'                 =>  $get_account_manager->role_id,
            'description'             =>  $get_account_manager->first_name . ' ' . $get_account_manager->last_name . ' ' . __('site.create_group'),
        ]);

        return redirect()->route('accountmanager.group.view-group')->with('message', __('site.record_added_group'));
    }

    // Group Create
    public function create(array $data)
    {
        return Group::create([
            'name' => $data['name'],
            'account_manager_id' => $data['account_manager_id'],
            'client_id' => $data['client_id'],
            'sub_account_id' => $data['sub_account_id'],
            'role_id' => $data['role_id'],
            'created_by' => $data['created_by'],
        ]);
    }

    // Group Listing View
    public function view()
    {
        $groups = Group::where('deleted_at', null)->with('created_by', 'role')->get();
        return view('accountmanager.group.view-group', compact('groups'));
    }


    // View Group Contacts
    public function viewcontacts()
    {

        return view('accountmanager.group.group-contact-list');
    }


    //Edit Group Form View
    public function edit($id)
    {
        $clients = Client::where('deleted_at', null)->get();
        $subaccounts = SubAccount::where('deleted_at', null)->get();

        $group = Group::where('id', $id)->first();

        return view('accountmanager.group.edit-group', compact('clients', 'subaccounts', 'group'));
    }


    // Update Group
    public function update(Request $request, $id)
    {
        $this->validate(request(), [
            'name' => 'required',
            'created_by'    =>    'required',
            'role_id'    =>    'required',
        ]);
        $group    = Group::find($id);

        $group->name      =   $request['name'];
        $group->account_manager_id    =   $request['account_manager_id'];
        $group->client_id      =   $request['client_id'];
        $group->sub_account_id      =   $request['sub_account_id'];
        $group->role_id      =   $request['role_id'];
        $group->created_by      =   $request['created_by'];

        $group->save();

        // Generate Log On Update Group
        $get_account_manager = (Auth::guard('account_manager')->user());
        $account_manager_register_log = AccountManagerLogs::create([

            'account_manager_id'      =>  $get_account_manager->id,
            'role_id'                 =>  $get_account_manager->role_id,
            'description'             =>  $get_account_manager->first_name . ' ' . $get_account_manager->last_name . ' ' . __('site.update_group'),
        ]);

        return redirect()->route('accountmanager.group.view-group')->with('message', __('site.group_edit_successfully'));
    }


    // Group Detail View
    public function detail($id)
    {
        $group = Group::where('id', $id)->with('created_by', 'account_manager', 'client', 'sub_account')->first();

        return view('accountmanager.group.detail-group', compact('group'));
    }

    
    // Delete Group
    public function delete($id)
    {
        $group = Group::where('id', '=', $id)->delete();

        // Generate Log On Delete Group
        $get_account_manager = (Auth::guard('account_manager')->user());
        $account_manager_register_log = AccountManagerLogs::create([

            'account_manager_id'      =>  $get_account_manager->id,
            'role_id'                 =>  $get_account_manager->role_id,
            'description'             =>  $get_account_manager->first_name . ' ' . $get_account_manager->last_name . ' ' . __('site.delete_group'),
        ]);

        return redirect()->route('accountmanager.group.view-group')->with('message', __('site.group_deleted_successfully'));
    }
}
