<?php

namespace App\Http\Controllers\AccountManager;

use App\Http\Controllers\Controller;
use App\Models\AccountManagerLogs;
use App\Models\Pipeline;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class AccountManagerPipelineController extends Controller
{
    // Return View Pipeline
    public function index()
    {

        $pipeline = Pipeline::get();
        return view('accountmanager.pipeline.view-pipeline', compact('pipeline'));
    }

    // Return View Add Pipeline
    public function addpipeline()
    {

        return view('accountmanager.pipeline.add-pipeline');
    }


    // Pipeline creation
    public function createpipeline(Request $request)
    {

        $request->validate([
            'first_name' => 'required',
            'last_name' => 'required',
            'email' => 'required',
            'mobile' => 'required',
            'company_name' => 'required',
            'created_by'    =>    'required',
            'description'   =>  'required',
        ]);

        $data = $request->all();
        $check = $this->create($data);

        // Generate Log On Create Pipeline
        $get_account_manager = (Auth::guard('account_manager')->user());
        $account_manager_register_log = AccountManagerLogs::create([

            'account_manager_id'      =>  $get_account_manager->id,
            'role_id'                 =>  $get_account_manager->role_id,
            'description'             =>  $get_account_manager->first_name . ' ' . $get_account_manager->last_name . ' ' . __('site.create_pipeline'),
        ]);

        return redirect()->route('accountmanager.pipeline.view-pipeline')->with('message', __('site.record_added_pipeline'));
    }

    // Pipeline Create
    public function create(array $data)
    {
        return Pipeline::create([
            'first_name' => $data['first_name'],
            'last_name' => $data['last_name'],
            'email' => $data['email'],
            'mobile' => $data['mobile'],
            'company_name'  =>  $data['company_name'],
            'created_by'  =>  $data['created_by'],
            'description'  =>  $data['description'],
        ]);
    }


    // Pipeline Edit Form View
    public function edit($id)
    {
        $pipeline = Pipeline::where('id', $id)->first();
        return view('accountmanager.pipeline.edit-pipeline',compact('pipeline'));
    }


    // Update Pipeline
    public function update(Request $request, $id)
    {
        $this->validate(request(), [
            'first_name' => 'required',
            'last_name' => 'required',
            'email' => 'required|email|unique:account_managers',
            'mobile' => 'required',
            'company_name' => 'required',
            'created_by'    =>    'required',
            'description'   =>  'required',
        ]);
        $pipeline    = Pipeline::find($id);

        $pipeline->first_name      =   $request['first_name'];
        $pipeline->last_name    =   $request['last_name'];
        $pipeline->email      =   $request['email'];
        $pipeline->mobile  =   $request['mobile'];
        $pipeline->company_name  =   $request['company_name'];
        $pipeline->description  =   $request['description'];
        $pipeline->created_by  =   $request['created_by'];

        $pipeline->save();

        // Generate Log On Update Pipeline
        $get_account_manager = (Auth::guard('account_manager')->user());
        $account_manager_register_log = AccountManagerLogs::create([

            'account_manager_id'      =>  $get_account_manager->id,
            'role_id'                 =>  $get_account_manager->role_id,
            'description'             =>  $get_account_manager->first_name . ' ' . $get_account_manager->last_name . ' ' . __('site.update_pipeline'),
        ]);
       
        return redirect()->route('accountmanager.pipeline.view-pipeline')->with('message', __('site.pipeline_edit_successfully'));
    }


    // Pipeline Detail View
    public function detail($id)
    {

        $pipeline = Pipeline::where('id', $id)->first();
        return view('accountmanager.pipeline.detail-pipeline', compact('pipeline'));
    }


    // Delete Pipeline
    public function delete($id)
    {
        $pipeline = Pipeline::where('id', '=', $id)->delete();

        // Generate Log On Delete Pipeline
        $get_account_manager = (Auth::guard('account_manager')->user());
        $account_manager_register_log = AccountManagerLogs::create([

            'account_manager_id'      =>  $get_account_manager->id,
            'role_id'                 =>  $get_account_manager->role_id,
            'description'             =>  $get_account_manager->first_name . ' ' . $get_account_manager->last_name . ' ' . __('site.delete_pipeline'),
        ]);

        return redirect()->route('accountmanager.pipeline.view-pipeline')->with('message', __('site.pipeline_deleted_successfully'));
    }
}
