<?php

namespace App\Http\Controllers\AccountManager;

use App\Http\Controllers\Controller;
use App\Models\AccountManagerLogs;
use App\Models\Client;
use App\Models\Masking;
use App\Models\SubAccount;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash as FacadesHash;

class AccountManagerSubAccountController extends Controller
{
    // Create Sub Account Form View
    public function index()
    {
        $clients = Client::where('deleted_at', null)->get();

        $masking = Masking::where('deleted_at', null)->get();

        return view('accountmanager.subaccount.add-sub-account', compact('clients', 'masking'));
    }


    // Sub Account Registeration
    public function registersubaccount(Request $request)
    {

        $request->validate([
            'client_id' => 'required',
            'masking_id' => 'required',
            'first_name' => 'required',
            'last_name' => 'required',
            'email' => 'required|email|unique:sub_accounts',
            'mobile' => 'required|unique:sub_accounts',
            'password' => 'required|min:6',
            'company_name' => 'required',
            'sms_limit' => 'required',
            'tenure' => 'required',
            'role_id'    =>    'required',
            'created_by'    =>    'required',
        ]);

        $data = $request->all();
        $check = $this->create($data);

        // Generate Log On Create Sub Account
        $get_account_manager = (Auth::guard('account_manager')->user());
        $account_manager_register_log = AccountManagerLogs::create([

            'account_manager_id'      =>  $get_account_manager->id,
            'role_id'                 =>  $get_account_manager->role_id,
            'description'             =>  $get_account_manager->first_name . ' ' . $get_account_manager->last_name . ' ' . __('site.create_subaccount'),
        ]);

        return redirect()->route('accountmanager.subaccount.view-active-sub-account')->with('message', __('site.subaccount_add_successfully'));
    }

    // Sub Account Create
    public function create(array $data)
    {
        return SubAccount::create([
            'client_id' => $data['client_id'],
            'masking_id' => $data['masking_id'],
            'first_name' => $data['first_name'],
            'last_name' => $data['last_name'],
            'email' => $data['email'],
            'mobile' => $data['mobile'],
            'password' => FacadesHash::make($data['password']),
            'company_name'  =>  $data['company_name'],
            'sms_limit'  =>  $data['sms_limit'],
            'tenure'  =>  $data['tenure'],
            'role_id'  =>  $data['role_id'],
            'created_by'  =>  $data['created_by'],
            'is_active'  =>  '1',
        ]);
    }


    // Active Sub Account Listing
    public function viewactive()
    {
        $subaccounts = SubAccount::where('is_active', '1')->get();

        return view('accountmanager.subaccount.view-active-sub-account', compact('subaccounts'));
    }


    // In Active Sub Account Listing
    public function viewinactive()
    {

        $subaccounts = SubAccount::where('is_active', '0')->get();

        return view('accountmanager.subaccount.view-inactive-sub-account', compact('subaccounts'));
    }


    // Edit Sub Account Form View
    public function edit($id)
    {

        $clients = Client::where('deleted_at', null)->get();

        $masking = Masking::where('deleted_at', null)->get();

        $subaccount = SubAccount::where('id', $id)->first();

        return view('accountmanager.subaccount.edit-sub-account', compact('subaccount', 'clients', 'masking'));
    }


    // Update Sub Account
    public function update(Request $request, $id)
    {
        $this->validate(request(), [
            'client_id' => 'required',
            'masking_id' => 'required',
            'first_name' => 'required',
            'last_name' => 'required',
            'email' => 'required|email|',
            'mobile' => 'required|',
            'password' => 'required|min:6',
            'sms_limit' => 'required',
            'tenure' => 'required',
            'role_id'    =>    'required',
            'created_by'    =>    'required',
        ]);

        $subaccount    = SubAccount::find($id);

        $subaccount->client_id      =   $request['client_id'];
        $subaccount->masking_id      =   $request['masking_id'];
        $subaccount->first_name      =   $request['first_name'];
        $subaccount->last_name    =   $request['last_name'];
        $subaccount->email      =   $request['email'];
        $subaccount->mobile  =   $request['mobile'];
        $subaccount->password = FacadesHash::make($request['password']);
        $subaccount->sms_limit  =   $request['sms_limit'];
        $subaccount->tenure  =   $request['tenure'];
        $subaccount->role_id  =   $request['role_id'];
        $subaccount->created_by  =   $request['created_by'];

        $subaccount->save();

        // Generate Log On Update Sub Account
        $get_account_manager = (Auth::guard('account_manager')->user());
        $account_manager_register_log = AccountManagerLogs::create([

            'account_manager_id'      =>  $get_account_manager->id,
            'role_id'                 =>  $get_account_manager->role_id,
            'description'             =>  $get_account_manager->first_name . ' ' . $get_account_manager->last_name . ' ' . __('site.update_subaccount'),
        ]);

        return redirect()->route('accountmanager.subaccount.view-active-sub-account')->with('message', __('site.subaccount_edit_successfully'));
    }


    // Detail View Page Sub Account
    public function view($id)
    {
        $subaccount = SubAccount::where('id', $id)->with('client', 'masking')->first();
        return view('accountmanager.subaccount.view-sub-account', compact('subaccount'));
    }



    // Delete Sub Account
    public function delete($id)
    {
        $subaccount = SubAccount::where('id', '=', $id)->delete();

        // Generate Log On Delete Sub Account
        $get_account_manager = (Auth::guard('account_manager')->user());
        $account_manager_register_log = AccountManagerLogs::create([

            'account_manager_id'      =>  $get_account_manager->id,
            'role_id'                 =>  $get_account_manager->role_id,
            'description'             =>  $get_account_manager->first_name . ' ' . $get_account_manager->last_name . ' ' . __('site.delete_subaccount'),
        ]);

        return redirect()->route('accountmanager.subaccount.view-active-sub-account')->with('message', __('site.subaccount_deleted_successfully'));
    }


     // Activate Sub Account
     public function activate($id)
     {
         $subaccount = SubAccount::where('id' , '=' , $id)->update([
             'is_active' => '1',
         ]);
 
         // Generate Log On Activate Sub Account
         $get_account_manager = (Auth::guard('account_manager')->user());
         $account_manager_register_log = AccountManagerLogs::create([
 
             'account_manager_id'      =>  $get_account_manager->id,
             'role_id'                 =>  $get_account_manager->role_id,
             'description'             =>  $get_account_manager->first_name . ' ' . $get_account_manager->last_name . ' ' . __('site.activate_subaccount'),
         ]);
 
         return redirect()->route('accountmanager.subaccount.view-active-sub-account')->with('message', __('site.subaccount_activate_successfully'));
     }
 
     // Deactivate Sub Account
     public function deactivate($id)
     {
         $subaccount = SubAccount::where('id' , '=' , $id)->update([
             'is_active' => '0',
         ]);
 
         // Generate Log On Deactivate Sub Account
         $get_account_manager = (Auth::guard('account_manager')->user());
         $account_manager_register_log = AccountManagerLogs::create([
 
             'account_manager_id'      =>  $get_account_manager->id,
             'role_id'                 =>  $get_account_manager->role_id,
             'description'             =>  $get_account_manager->first_name . ' ' . $get_account_manager->last_name . ' ' . __('site.deactivate_subaccount'),
         ]);
 
         return redirect()->route('accountmanager.subaccount.view-inactive-sub-account')->with('message', __('site.subaccount_deactivate_successfully'));
     }
}
