<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AccountManager;
use App\Models\AdminLogs;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash as FacadesHash;
use Mail;

class AdminAccountManagerController extends Controller
{
    // Return View Add Account Manager
    public function index()
    {

        return view('admin.accountmanager.add-account-manager');
    }


    // Account Manager Registeration
    public function registeraccountmanager(Request $request)
    {

        $request->validate([
            'first_name' => 'required',
            'last_name' => 'required',
            'email' => 'required|email|unique:account_managers',
            'mobile' => 'required|unique:account_managers',
            'password' => 'required|min:6',
            'role_id'    =>    'required',
            'created_by'    =>    'required',
        ]);

        $data = $request->all();
        $check = $this->create($data);

        // Generate Log On Create Account Manager
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.create_account_manager'),
        ]);

        return redirect()->route('admin.accountmanager.view-active-account-manager')->with('message', __('site.account_manager_add_successfully'));
    }


    // Account Manager Create
    public function create(array $data)
    {
        return AccountManager::create([
            'first_name' => $data['first_name'],
            'last_name' => $data['last_name'],
            'email' => $data['email'],
            'mobile' => $data['mobile'],
            'role_id'  =>  $data['role_id'],
            'created_by'  =>  $data['created_by'],
            'is_active'  =>  '1',
            'password' => FacadesHash::make($data['password'])
        ]);
    }


    // Active Account Managers
    public function viewactivemanagers()
    {

        $active_accountmanager = AccountManager::where('is_active', '1')->get();

        return view('admin.accountmanager.view-active-account-manager', compact('active_accountmanager'));
    }


    // In Active Account Managers
    public function viewinactivemanagers()
    {

        $inactive_accountmanager = AccountManager::where('is_active', '0')->get();

        return view('admin.accountmanager.view-inactive-account-manager', compact('inactive_accountmanager'));
    }


    // Return Edit View
    public function edit($id)
    {

        $accountmanager_detail = AccountManager::where('id', $id)->first();

        return view('admin.accountmanager.edit-account-manager', compact('accountmanager_detail'));
    }


    // Update Account Manager
    public function update(Request $request, $id)
    {
        $this->validate(request(), [
            'first_name' => 'required',
            'last_name' => 'required',
            'email' => 'required',
            'mobile' => 'required',
            'role_id'    =>    'required',
            'created_by'    =>    'required',
        ]);

        $accountmanager    = AccountManager::find($id);

        $accountmanager->first_name      =   $request['first_name'];
        $accountmanager->last_name    =   $request['last_name'];
        $accountmanager->email      =   $request['email'];
        $accountmanager->mobile  =   $request['mobile'];
        $accountmanager->role_id  =   $request['role_id'];
        $accountmanager->created_by  =   $request['created_by'];
        $accountmanager->password = FacadesHash::make($request['password']);

        $accountmanager->save();

        // Generate Log On Update Account Manager
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.update_account_manager'),
        ]);

        return redirect()->route('admin.accountmanager.view-active-account-manager')->with('message', __('site.account_manager_edit_successfully'));
    }

    // View Account Manager
    public function view($id)
    {

        $accountmanager = AccountManager::where('id', $id)->first();

        return view('admin.accountmanager.view-account-manager', compact('accountmanager'));
    }

    // Delete Account Manager
    public function delete($id)
    {
        $accountmanager = AccountManager::where('id', '=', $id)->delete();

        // Generate Log On Delete Account Manager
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.delete_account_manager'),
        ]);

        return redirect()->route('admin.accountmanager.view-active-account-manager')->with('message', __('site.account_manager_deleted_successfully'));
    }

    // Activate Account Manager
    public function activate($id)
    {
        $accountmanager = AccountManager::where('id' , '=' , $id)->update([
            'is_active' => '1',
        ]);

        // Generate Log On Activate Account Manager
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.activate_account_manager'),
        ]);

        return redirect()->route('admin.accountmanager.view-active-account-manager')->with('message', __('site.account_manager_activate_successfully'));
    }

    // Deactivate Account Manager
    public function deactivate($id)
    {
        $accountmanager = AccountManager::where('id' , '=' , $id)->update([
            'is_active' => '0',
        ]);

        // Generate Log On Deactivate Account Manager
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.deactivate_account_manager'),
        ]);

        return redirect()->route('admin.accountmanager.view-inactive-account-manager')->with('message', __('site.account_manager_deactivate_successfully'));
    }
}
