<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
// Use Auth;
use Illuminate\Support\Facades\Auth;
use Hash;
use Session;
use App\Models\User;
use App\Models\Admin;
use App\Models\AdminLogs;
use Illuminate\Support\Facades\Hash as FacadesHash;
use Illuminate\Support\Facades\Session as FacadesSession;

class AdminAuthController extends Controller
{

    // Authentication form view
    public function index()
    {
        return view('admin.auth.login');
    }

    // Custom login form
    public function customLogin(Request $request)
    {
        $request->validate([
            'email' => 'required',
            'password' => 'required',
        ]);

        // Generate Log On Admin Login
        $credentials = $request->only('email', 'password');
        if (Auth::guard('admin')->attempt($credentials)) {

            $get_admin = (Auth::guard('admin')->user());
            $admin_login_log    =   AdminLogs::create([

                'admin_id'      =>  $get_admin->id,
                'role_id'       =>  $get_admin->role_id,
                'description'   =>  $get_admin->first_name .' '. $get_admin->last_name .' '. __('site.login_successfully'),
            ]);

            return redirect()->intended('admin\dashboard')
                ->with('message', __('site.login_successfully'));
        }
        return redirect()->route('admin')->with('message', __('site.record_not_found'));
    }

    // Registration form view
    public function registration()
    {
        return view('admin.auth.registration');
    }

    // Custom registration form
    public function customRegistration(Request $request)
    {
        $request->validate([
            'first_name' => 'required',
            'last_name' => 'required',
            'email' => 'required|email|unique:users',
            'mobile' => 'required',
            'password' => 'required|min:6',
            'role_id'    =>    'required',
        ]);

        $data = $request->all();
        $check = $this->create($data);

        // Generate Log On Admin Registration
        $admin_register_log = AdminLogs::create([

            'admin_id'       =>  '1',
            'role_id'       =>   '1',
            'description'   =>  __('site.admin_created'),
        ]);

        return redirect()->route('admin')->with('message', __('site.registered_successfully'));
    }

    // Create user
    public function create(array $data)
    {
      return Admin::create([
        'first_name' => $data['first_name'],
        'last_name' => $data['last_name'],
        'email' => $data['email'],
        'mobile' => $data['mobile'],
        'role_id'  =>  $data['role_id'],
        'password' => FacadesHash::make($data['password'])
      ]);
    }

    // Return view after authentication
    public function dashboard()
    {
        
        if(Auth::check()){
            return view('dashboard');
        }

        return redirect("login")->withSuccess('You are not allowed to access');
    }

    // Admin signout
    public function signOut() {

        // Generate Log On Admin Logout
            $admin_logout_log    =   AdminLogs::create([
                'admin_id'       =>  '1',
                'role_id'       =>   '1',
                'description'   =>  __('site.admin_logout'),
            ]);

        FacadesSession::flush();
        Auth::guard('admin')->logout();

        return Redirect('admin');
    }
}


