<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AccountManager;
use App\Models\AdminLogs;
use App\Models\Client;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash as FacadesHash;

class AdminClientController extends Controller
{
    // Return View Add Client
    public function index()
    {

        $account_managers = AccountManager::where('is_active', '1')->get();

        return view('admin.client.add-client', compact('account_managers'));
    }

    // Client Registeration
    public function registerclient(Request $request)
    {

        $request->validate([
            'first_name' => 'required',
            'last_name' => 'required',
            'email' => 'required|email|unique:clients',
            'mobile' => 'required|unique:clients',
            'password' => 'required|min:6',
            'company_name' => 'required',
            'sms_limit' => 'required',
            'account_manager_id' => 'required',
            'tenure' => 'required',
            'role_id'    =>    'required',
            'created_by'    =>    'required',
        ]);

        $data = $request->all();
        $check = $this->create($data);

        // Generate Log On Create Client
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.create_client'),
        ]);

        return redirect()->route('admin.client.view-active-client')->with('message', __('site.client_add_successfully'));
    }

    // Client Create
    public function create(array $data)
    {
        return Client::create([
            'first_name' => $data['first_name'],
            'last_name' => $data['last_name'],
            'email' => $data['email'],
            'mobile' => $data['mobile'],
            'password' => FacadesHash::make($data['password']),
            'company_name'  =>  $data['company_name'],
            'sms_limit'  =>  $data['sms_limit'],
            'account_manager_id'  =>  $data['account_manager_id'],
            'tenure'  =>  $data['tenure'],
            'role_id'  =>  $data['role_id'],
            'created_by'  =>  $data['created_by'],
            'is_active'  =>  '1',
        ]);
    }

    // Active Clients
    public function viewactiveclients()
    {

        $clients = Client::where('is_active', '1')->get();

        return view('admin.client.view-active-client', compact('clients'));
    }

    // In Active Clients
    public function viewinactiveclients()
    {

        $clients = Client::where('is_active', '0')->get();

        return view('admin.client.view-inactive-client', compact('clients'));
    }

    // Return Edit View
    public function edit($id)
    {

        $account_managers = AccountManager::where('is_active', '1')->get();
        $client = Client::where('id', $id)->first();

        return view('admin.client.edit-client', compact('client', 'account_managers'));
    }

    // Update Client
    public function update(Request $request, $id)
    {
        $this->validate(request(), [
            'first_name' => 'required',
            'last_name' => 'required',
            'email' => 'required|email|unique:account_managers',
            'mobile' => 'required|unique:account_managers',
            'password' => 'required|min:6',
            'sms_limit' => 'required',
            'account_manager_id' => 'required',
            'tenure' => 'required',
            'role_id'    =>    'required',
            'created_by'    =>    'required',
        ]);

        $client    = Client::find($id);

        $client->first_name      =   $request['first_name'];
        $client->last_name    =   $request['last_name'];
        $client->email      =   $request['email'];
        $client->mobile  =   $request['mobile'];
        $client->password = FacadesHash::make($request['password']);
        $client->sms_limit  =   $request['sms_limit'];
        $client->account_manager_id  =   $request['account_manager_id'];
        $client->tenure  =   $request['tenure'];
        $client->role_id  =   $request['role_id'];
        $client->created_by  =   $request['created_by'];

        $client->save();

        // Generate Log On Update Client
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.update_client'),
        ]);

        return redirect()->route('admin.client.view-active-client')->with('message', __('site.client_edit_successfully'));
    }


    // View Client
    public function view($id)
    {

        $client = Client::where('id', $id)->first();

        return view('admin.client.view-client', compact('client'));
    }

    // Delete Client
    public function delete($id)
    {
        $client = Client::where('id', '=', $id)->delete();

        // Generate Log On Delete Client
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.delete_client'),
        ]);

        return redirect()->route('admin.client.view-active-client')->with('message', __('site.client_deleted_successfully'));
    }

    // Activate Client
    public function activate($id)
    {
        $client = Client::where('id' , '=' , $id)->update([
            'is_active' => '1',
        ]);

        // Generate Log On Activate Client
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.activate_client'),
        ]);

        return redirect()->route('admin.client.view-active-client')->with('message', __('site.client_activate_successfully'));
    }

    // Deactivate Client
    public function deactivate($id)
    {
        $client = Client::where('id' , '=' , $id)->update([
            'is_active' => '0',
        ]);

        // Generate Log On Deactivate Client
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.deactivate_client'),
        ]);

        return redirect()->route('admin.client.view-inactive-client')->with('message', __('site.client_deactivate_successfully'));
    }

}
