<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AccountManager;
use App\Models\AdminLogs;
use App\Models\Client;
use App\Models\Masking;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class AdminMaskingController extends Controller
{
    // Add Masking View
    public function addmasking()
    {

        $accountmanagers = AccountManager::where('deleted_at', null)->get();

        $clients = Client::where('deleted_at', null)->get();

        return view('admin.masking.add-masking', compact('accountmanagers', 'clients'));
    }


    // Masking creation
    public function createmasking(Request $request)
    {

        $request->validate([
            'masking' => 'required',
            'account_manager_id' => 'required',
            'client_id' => 'required',
        ]);

        $data = $request->all();
        $check = $this->create($data);

        // Generate Log On Create Masking
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.create_masking'),
        ]);

        return redirect()->route('admin.masking.view-active-masking')->with('message', __('site.record_added_masking'));
    }

    // Masking Create
    public function create(array $data)
    {
        return Masking::create([
            'masking' => $data['masking'],
            'account_manager_id' => $data['account_manager_id'],
            'client_id' => $data['client_id'],
            'is_active' => 1,
        ]);
    }

    // View Active Mssking
    public function viewactivemasking()
    {

        $active_masking = Masking::where('is_active', 1)->with('account_manager', 'client')->get();
        return view('admin.masking.view-active-masking', compact('active_masking'));
    }


    // View In-Active Masking
    public function viewinactivemasking()
    {

        $inactive_masking = Masking::where('is_active', 0)->with('account_manager', 'client')->get();
        return view('admin.masking.view-inactive-masking', compact('inactive_masking'));
    }


    // Edit Masking Form View
    public function edit($id)
    {

        $accountmanagers = AccountManager::where('deleted_at', null)->get();

        $clients = Client::where('deleted_at', null)->get();

        $masking = Masking::where('id', $id)->first();
        return view('admin.masking.edit-masking', compact('masking', 'accountmanagers', 'clients'));
    }


    // Update Masking
    public function update(Request $request, $id)
    {
        $this->validate(request(), [
            'masking' => 'required',
            'account_manager_id' => 'required',
            'client_id' => 'required',
        ]);
        $masking    = Masking::find($id);

        $masking->masking      =   $request['masking'];
        $masking->account_manager_id    =   $request['account_manager_id'];
        $masking->client_id      =   $request['client_id'];

        $masking->save();

        // Generate Log On Update Masking
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.update_masking'),
        ]);

        return redirect()->route('admin.masking.view-active-masking')->with('message', __('site.masking_edit_successfully'));
    }


    // Masking Detail View
    public function view($id)
    {

        $masking = Masking::where('id', $id)->with('account_manager', 'client')->first();

        return view('admin.masking.view-masking', compact('masking'));
    }


    // Activate Masking
    public function activate($id)
    {
        $masking = Masking::where('id', '=', $id)->update([
            'is_active' => '1',
        ]);

        // Generate Log On Activate Masking
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.activate_masking'),
        ]);

        return redirect()->route('admin.masking.view-active-masking')->with('message', __('site.masking_activate_successfully'));
    }

    // Deactivate Masking
    public function deactivate($id)
    {
        $masking = Masking::where('id', '=', $id)->update([
            'is_active' => '0',
        ]);

        // Generate Log On Deactivate Masking
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.deactivate_masking'),
        ]);

        return redirect()->route('admin.masking.view-inactive-masking')->with('message', __('site.masking_deactivate_successfully'));
    }


    // Delete Masking
    public function delete($id)
    {
        $masking = Masking::where('id', '=', $id)->delete();

        // Generate Log On Delete Masking
        $get_admin = (Auth::guard('admin')->user());
        $admin_register_log = AdminLogs::create([

            'admin_id'      =>  $get_admin->id,
            'role_id'       =>  $get_admin->role_id,
            'description'   =>  $get_admin->first_name . ' ' . $get_admin->last_name . ' ' . __('site.delete_masking'),
        ]);

        return redirect()->route('admin.masking.view-active-masking')->with('message', __('site.masking_deleted_successfully'));
    }
}
