<?php

namespace App\Http\Controllers\Client;

use App\Http\Controllers\Controller;
use App\Models\ClientLogs;
use App\Models\Group;
use App\Models\Contact;
use App\Models\SubAccount;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ClientContactController extends Controller
{
    //Create Contact Form View
    public function index()
    {

        $subaccounts = SubAccount::where('deleted_at', null)->get();
        $groups = Group::where('deleted_at', null)->get();

        return view('client.contact.add-contact', compact('subaccounts', 'groups'));
    }


    // Contact creation
    public function createcontact(Request $request)
    {

        $request->validate([
            'created_by'    =>    'required',
            'role_id'    =>    'required',
            'first_name' => 'required',
            'last_name' => 'required',
            'email'  => 'required',
            'mobile' => 'required',

        ]);

        $data = $request->all();
        $check = $this->create($data);

        // Generate Log On Create Contact
        $get_client = (Auth::guard('client')->user());
        $client_register_log = ClientLogs::create([

            'client_id'     =>  $get_client->id,
            'role_id'       =>  $get_client->role_id,
            'description'   =>  $get_client->first_name . ' ' . $get_client->last_name . ' ' . __('site.create_contact'),
        ]);

        return redirect()->route('client.contact.view-contact')->with('message', __('site.record_added_contact'));
    }

    // Contact Create
    public function create(array $data)
    {
        return Contact::create([
            'created_by' => $data['created_by'],
            'role_id' => $data['role_id'],
            'first_name' => $data['first_name'],
            'last_name' => $data['last_name'],
            'email' => $data['email'],
            'mobile' => $data['mobile'],
            'group_id' => $data['group_id'],
            'account_manager_id' => $data['account_manager_id'],
            'client_id' => $data['client_id'],
            'sub_account_id' => $data['sub_account_id'],
            'is_blocked' => 0,
        ]);
    }


    // Contact Listing Page
    public function view()
    {
        $contacts = Contact::where('deleted_at', null)->where('is_blocked', 0)->with('group')->get();

        return view('client.contact.view-contact', compact('contacts'));
    }


    // Contact Edit Form View
    public function edit($id)
    {
        $subaccounts = SubAccount::where('deleted_at', null)->get();
        $groups = Group::where('deleted_at', null)->get();

        $contact = Contact::where('id', $id)->first();

        return view('client.contact.edit-contact', compact('subaccounts', 'groups', 'contact'));
    }


    // Update Contact
    public function update(Request $request, $id)
    {
        $this->validate(request(), [
            'created_by'    =>    'required',
            'role_id'    =>    'required',
            'first_name' => 'required',
            'last_name' => 'required',
            'email'  => 'required',
            'mobile' => 'required',
        ]);

        $contact    = Contact::find($id);

        $contact->created_by      =   $request['created_by'];
        $contact->role_id    =   $request['role_id'];
        $contact->first_name      =   $request['first_name'];
        $contact->last_name      =   $request['last_name'];
        $contact->email      =   $request['email'];
        $contact->mobile      =   $request['mobile'];
        $contact->group_id      =   $request['group_id'];
        $contact->account_manager_id      =   $request['account_manager_id'];
        $contact->client_id      =   $request['client_id'];
        $contact->sub_account_id      =   $request['sub_account_id'];
        $contact->is_blocked      =   0;

        $contact->save();

        // Generate Log On Update Contact
        $get_client = (Auth::guard('client')->user());
        $client_register_log = ClientLogs::create([

            'client_id'     =>  $get_client->id,
            'role_id'       =>  $get_client->role_id,
            'description'   =>  $get_client->first_name . ' ' . $get_client->last_name . ' ' . __('site.update_contact'),
        ]);

        return redirect()->route('client.contact.view-contact')->with('message', __('site.contact_edit_successfully'));
    }


    // Contact Detail View Page
    public function detail($id)
    {
        $contact = Contact::where('id', $id)->with('group', 'account_manager', 'sub_account')->first();

        return view('client.contact.detail-contact', compact('contact'));
    }


    // Delete Contact
    public function delete($id)
    {
        $contact = Contact::where('id', '=', $id)->delete();

        // Generate Log On Delete Contact
        $get_client = (Auth::guard('client')->user());
        $client_register_log = ClientLogs::create([

            'client_id'     =>  $get_client->id,
            'role_id'       =>  $get_client->role_id,
            'description'   =>  $get_client->first_name . ' ' . $get_client->last_name . ' ' . __('site.delete_contact'),
        ]);

        return redirect()->route('client.contact.view-contact')->with('message', __('site.contact_deleted_successfully'));
    }


     // Block Contact
     public function block($id)
     {
         $contact = Contact::where('id' , '=' , $id)->update([
             'is_blocked' => '1',
         ]);
 
         // Generate Log On Block Contact
         $get_client = (Auth::guard('client')->user());
         $client_register_log = ClientLogs::create([
 
             'client_id'     =>  $get_client->id,
             'role_id'       =>  $get_client->role_id,
             'description'   =>  $get_client->first_name . ' ' . $get_client->last_name . ' ' . __('site.block_contact'),
         ]);
 
         return redirect()->route('client.contact.view-contact')->with('message', __('site.move_contact_blacklist'));
     }


    public function importcontactview()
    {

        return view('client.contact.import-contact');
    }
}
