<?php

use App\Http\Controllers\AccountManager\AccountManagerAuthController;
use App\Http\Controllers\AccountManager\AccountManagerBlacklistController;
use App\Http\Controllers\AccountManager\AccountManagerComplaintAndFeedbackController;
use App\Http\Controllers\AccountManager\AccountManagerContactController;
use App\Http\Controllers\AccountManager\AccountManagerDashboardController;
use App\Http\Controllers\AccountManager\AccountManagerClientController;
use App\Http\Controllers\AccountManager\AccountManagerPipelineController;
use App\Http\Controllers\AccountManager\AccountManagereSmsController;
use App\Http\Controllers\AccountManager\AccountManagerGroupController;
use App\Http\Controllers\AccountManager\AccountManagerLogsController;
use App\Http\Controllers\AccountManager\AccountManagerProfileController;
use App\Http\Controllers\AccountManager\AccountManagerSubAccountController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


// AccountManager Login And Registration
Route::get('/', [AccountManagerAuthController::class, 'index'])->name('accountmanager');
Route::post('custom-login', [AccountManagerAuthController::class, 'customLogin'])->name('accountmanager.login.custom');
Route::get('signout', [AccountManagerAuthController::class, 'signOut'])->name('accountmanager.signout');

Route::middleware(\App\Http\Middleware\AccountManagerAuthMiddleware::class)->group(function () {

    // AccountManager Dashboard
    Route::get('dashboard', [AccountManagerDashboardController::class, 'index'])->name('accountmanager.dashboard');

    // AccountManager Profile
    Route::get('profile', [AccountManagerProfileController::class, 'index'])->name('accountmanager.profile');

    // AccountManager SMS
    Route::get('sms/compose', [AccountManagereSmsController::class, 'compose'])->name('accountmanager.sms.compose');
    Route::get('sms/sent-items', [AccountManagereSmsController::class, 'sent_items'])->name('accountmanager.sms.sent-items');
    Route::get('sms/group-sms', [AccountManagereSmsController::class, 'group_sms'])->name('accountmanager.sms.group-sms');
    Route::get('sms/schedule-sms', [AccountManagereSmsController::class, 'schedule_sms'])->name('accountmanager.sms.schedule-sms');
    Route::get('sms/detail', [AccountManagereSmsController::class, 'view'])->name('accountmanager.sms.detail');

    // AccountManager Clients
    Route::get('client/add-client', [AccountManagerClientController::class, 'index'])->name('accountmanager.client.add-client');
    Route::post('accountmanager-client-register', [AccountManagerClientController::class, 'registerclient'])->name('accountmanager.client.register');
    Route::get('client/edit-client/{id}', [AccountManagerClientController::class, 'edit'])->name('accountmanager.client.edit-client');
    Route::post('client/edit-client/{id}', [AccountManagerClientController::class, 'update'])->name('accountmanager.client.edit');
    Route::get('client/view-client/{id}', [AccountManagerClientController::class, 'view'])->name('accountmanager.client.view-client');
    Route::get('client/view-active-client', [AccountManagerClientController::class, 'viewactiveclients'])->name('accountmanager.client.view-active-client');
    Route::get('client/view-inactive-client', [AccountManagerClientController::class, 'viewinactiveclients'])->name('accountmanager.client.view-inactive-client');
    Route::get('client/delete-client/{id}', [AccountManagerClientController::class, 'delete'])->name('accountmanager.client.delete');
    Route::get('client/activate-client/{id}', [AccountManagerClientController::class, 'activate'])->name('accountmanager.client.activate');
    Route::get('client/deactivate-client/{id}', [AccountManagerClientController::class, 'deactivate'])->name('accountmanager.client.deactivate');

    // AccountManager Pipeline
    Route::get('pipeline/add-pipeline', [AccountManagerPipelineController::class, 'addpipeline'])->name('accountmanager.pipeline.add-pipeline');
    Route::get('pipeline/view-pipeline', [AccountManagerPipelineController::class, 'index'])->name('accountmanager.pipeline.view-pipeline');
    Route::post('accountmanager-pipeline-create', [AccountManagerPipelineController::class, 'createpipeline'])->name('accountmanager.pipeline.create');
    Route::get('pipeline/edit-pipeline/{id}', [AccountManagerPipelineController::class, 'edit'])->name('accountmanager.pipeline.edit-pipeline');
    Route::post('pipeline/edit-pipeline/{id}', [AccountManagerPipelineController::class, 'update'])->name('accountmanager.pipeline.edit');
    Route::get('pipeline/detail-pipeline/{id}', [AccountManagerPipelineController::class, 'detail'])->name('accountmanager.pipeline.detail-pipeline');
    Route::get('pipeline/delete-pipeline/{id}', [AccountManagerPipelineController::class, 'delete'])->name('accountmanager.pipeline.delete');

    // AccountManager Sub Accounts
    Route::get('subaccount/add-sub-account', [AccountManagerSubAccountController::class, 'index'])->name('accountmanager.subaccount.add-sub-account');
    Route::post('accountmanager-subaccount-register', [AccountManagerSubAccountController::class, 'registersubaccount'])->name('accountmanager.subaccount.register');
    Route::get('subaccount/edit-sub-account/{id}', [AccountManagerSubAccountController::class, 'edit'])->name('accountmanager.subaccount.edit-sub-account');
    Route::post('subaccount/edit-sub-account/{id}', [AccountManagerSubAccountController::class, 'update'])->name('accountmanager.subaccount.edit');
    Route::get('subaccount/view-sub-account/{id}', [AccountManagerSubAccountController::class, 'view'])->name('accountmanager.subaccount.view-sub-account');
    Route::get('subaccount/view-active-sub-account', [AccountManagerSubAccountController::class, 'viewactive'])->name('accountmanager.subaccount.view-active-sub-account');
    Route::get('subaccount/view-inactive-sub-account', [AccountManagerSubAccountController::class, 'viewinactive'])->name('accountmanager.subaccount.view-inactive-sub-account');
    Route::get('subaccount/delete-sub-account/{id}', [AccountManagerSubAccountController::class, 'delete'])->name('accountmanager.subaccount.delete');
    Route::get('subaccount/activate-sub-account/{id}', [AccountManagerSubAccountController::class, 'activate'])->name('accountmanager.subaccount.activate');
    Route::get('subaccount/deactivate-sub-account/{id}', [AccountManagerSubAccountController::class, 'deactivate'])->name('accountmanager.subaccount.deactivate');

    // AccountManager Groups
    Route::get('group/add-group', [AccountManagerGroupController::class, 'index'])->name('accountmanager.group.add-group');
    Route::post('accountmanager-group-create', [AccountManagerGroupController::class, 'creategroup'])->name('accountmanager.group.create');
    Route::get('group/view-group', [AccountManagerGroupController::class, 'view'])->name('accountmanager.group.view-group');
    Route::get('group/edit-group/{id}', [AccountManagerGroupController::class, 'edit'])->name('accountmanager.group.edit-group');
    Route::post('group/edit-group/{id}', [AccountManagerGroupController::class, 'update'])->name('accountmanager.group.edit');
    Route::get('group/detail-group/{id}', [AccountManagerGroupController::class, 'detail'])->name('accountmanager.group.detail-group');
    Route::get('group/group-contact-list', [AccountManagerGroupController::class, 'viewcontacts'])->name('accountmanager.group.group-contact-list');
    Route::get('group/delete-group/{id}', [AccountManagerGroupController::class, 'delete'])->name('accountmanager.group.delete');

    // AccountManager Contacts
    Route::get('contact/add-contact', [AccountManagerContactController::class, 'index'])->name('accountmanager.contact.add-contact');
    Route::post('accountmanager-contact-create', [AccountManagerContactController::class, 'createcontact'])->name('accountmanager.contact.create');
    Route::get('contact/view-contact', [AccountManagerContactController::class, 'view'])->name('accountmanager.contact.view-contact');
    Route::get('contact/edit-contact/{id}', [AccountManagerContactController::class, 'edit'])->name('accountmanager.contact.edit-contact');
    Route::post('contact/edit-contact/{id}', [AccountManagerContactController::class, 'update'])->name('accountmanager.contact.edit');
    Route::get('contact/detail-contact/{id}', [AccountManagerContactController::class, 'detail'])->name('accountmanager.contact.detail-contact');
    Route::get('contact/delete-contact/{id}', [AccountManagerContactController::class, 'delete'])->name('accountmanager.contact.delete');
    Route::get('contact/block-contact/{id}', [AccountManagerContactController::class, 'block'])->name('accountmanager.contact.block');
    Route::get('contact/import-contact', [AccountManagerContactController::class, 'importcontactview'])->name('accountmanager.contact.import-contact');

    // AccountManager Logs
    Route::get('logs/account-manager-logs', [AccountManagerLogsController::class, 'accountmanagerlogs'])->name('accountmanager.logs.account-manager-logs');
    Route::get('logs/client-logs', [AccountManagerLogsController::class, 'client'])->name('accountmanager.logs.client-logs');
    Route::get('logs/sub-account-logs', [AccountManagerLogsController::class, 'subaccountlogs'])->name('accountmanager.logs.sub-account-logs');

    // AccountManager Blacklist
    Route::get('blacklist/view-client-blacklist', [AccountManagerBlacklistController::class, 'clientsblacklist'])->name('accountmanager.blacklist.view-client-blacklist');
    Route::get('blacklist/view-sub-account-blacklist', [AccountManagerBlacklistController::class, 'subaccountsblacklist'])->name('accountmanager.blacklist.view-sub-account-blacklist');
    Route::get('blacklist/detail-blacklist', [AccountManagerBlacklistController::class, 'detail'])->name('accountmanager.blacklist.detail-blacklist');

    // AccountManager Complains And Feedback
    Route::get('complaintsandfeedback/acc-manager-feedback', [AccountManagerComplaintAndFeedbackController::class, 'accountmanagerfeedback'])->name('accountmanager.complaintsandfeedback.acc-manager-feedback');
    Route::get('complaintsandfeedback/client-feedback', [AccountManagerComplaintAndFeedbackController::class, 'clientfeedback'])->name('accountmanager.complaintsandfeedback.client-feedback');
    Route::get('complaintsandfeedback/sub-account-feedback', [AccountManagerComplaintAndFeedbackController::class, 'subaccountfeedback'])->name('accountmanager.complaintsandfeedback.sub-account-feedback');
    Route::get('complaintsandfeedback/detail-feedback', [AccountManagerComplaintAndFeedbackController::class, 'detail'])->name('accountmanager.complaintsandfeedback.detail-feedback');
});
