<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Admin\AdminAuthController;
use App\Http\Controllers\Admin\AdminDashboardController;
use App\Http\Controllers\Admin\AdminAccountManagerController;
use App\Http\Controllers\Admin\AdminBlacklistController;
use App\Http\Controllers\Admin\AdminClientController;
use App\Http\Controllers\Admin\AdminComplaintAndFeedbackController;
use App\Http\Controllers\Admin\AdminPipelineController;
use App\Http\Controllers\Admin\AdminSubAccountController;
use App\Http\Controllers\Admin\AdminGroupController;
use App\Http\Controllers\Admin\AdminContactController;
use App\Http\Controllers\Admin\AdminDemoAccountController;
use App\Http\Controllers\Admin\AdminLogsController;
use App\Http\Controllers\Admin\AdminMaskingController;
use App\Http\Controllers\Admin\AdminProfileController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


// Admin Login And Registration
Route::get('/', [AdminAuthController::class, 'index'])->name('admin');
Route::post('custom-login', [AdminAuthController::class, 'customLogin'])->name('admin.login.custom');
Route::get('admin/auth/register', [AdminAuthController::class, 'registration'])->name('admin.auth.registration');
Route::post('custom-registration', [AdminAuthController::class, 'customRegistration'])->name('admin.register.custom');
Route::get('signout', [AdminAuthController::class, 'signOut'])->name('admin.signout');

Route::middleware(\App\Http\Middleware\AdminAuthMiddleware::class)->group(function(){

    // Admin Dashboard
    Route::get('dashboard', [AdminDashboardController::class, 'index'])->name('admin.dashboard');

    // Admin Profile
    Route::get('profile', [AdminProfileController::class, 'index'])->name('admin.profile');

    // Admin Masking
    Route::get('masking/add-masking', [AdminMaskingController::class, 'addmasking'])->name('admin.masking.add-masking');
    Route::post('admin-masking-create', [AdminMaskingController::class, 'createmasking'])->name('admin.masking.create');
    Route::get('masking/edit-masking/{id}', [AdminMaskingController::class, 'edit'])->name('admin.masking.edit-masking');
    Route::post('masking/edit-masking/{id}', [AdminMaskingController::class, 'update'])->name('admin.masking.edit');
    Route::get('masking/view-masking/{id}', [AdminMaskingController::class, 'view'])->name('admin.masking.view-masking');
    Route::get('masking/view-active-masking', [AdminMaskingController::class, 'viewactivemasking'])->name('admin.masking.view-active-masking');
    Route::get('masking/view-inactive-masking', [AdminMaskingController::class, 'viewinactivemasking'])->name('admin.masking.view-inactive-masking');
    Route::get('masking/activate-masking/{id}', [AdminMaskingController::class, 'activate'])->name('admin.masking.activate');
    Route::get('masking/deactivate-masking/{id}', [AdminMaskingController::class, 'deactivate'])->name('admin.masking.deactivate');
    Route::get('masking/delete-masking/{id}', [AdminMaskingController::class, 'delete'])->name('admin.masking.delete');

    // Admin Trial User
    Route::get('demoaccount/view-trial-user', [AdminDemoAccountController::class, 'view'])->name('admin.demoaccount.view-trial-user');
    Route::get('demoaccount/view-active-trial-user', [AdminDemoAccountController::class, 'viewactivetrialuser'])->name('admin.demoaccount.view-active-trial-user');
    Route::get('demoaccount/view-inactive-trial-user', [AdminDemoAccountController::class, 'viewinactivetrialuser'])->name('admin.demoaccount.view-inactive-trial-user');

    // Admin Account Manager
    Route::get('accountmanager/add-account-manager', [AdminAccountManagerController::class, 'index'])->name('admin.accountmanager.add-account-manager');
    Route::post('admin-accountmanager-register', [AdminAccountManagerController::class, 'registeraccountmanager'])->name('admin.accountmanager.register');
    Route::get('accountmanager/edit-account-manager/{id}', [AdminAccountManagerController::class, 'edit'])->name('admin.accountmanager.edit-account-manager');
    Route::post('accountmanager/edit-account-manager/{id}', [AdminAccountManagerController::class, 'update'])->name('admin.accountmanager.edit');
    Route::get('accountmanager/view-account-manager/{id}', [AdminAccountManagerController::class, 'view'])->name('admin.accountmanager.view-account-manager');
    Route::get('accountmanager/view-active-account-manager', [AdminAccountManagerController::class, 'viewactivemanagers'])->name('admin.accountmanager.view-active-account-manager');
    Route::get('accountmanager/view-inactive-account-manager', [AdminAccountManagerController::class, 'viewinactivemanagers'])->name('admin.accountmanager.view-inactive-account-manager');
    Route::get('accountmanager/delete-account-manager/{id}', [AdminAccountManagerController::class, 'delete'])->name('admin.accountmanager.delete');
    Route::get('accountmanager/activate-account-manager/{id}', [AdminAccountManagerController::class, 'activate'])->name('admin.accountmanager.activate');
    Route::get('accountmanager/deactivate-account-manager/{id}', [AdminAccountManagerController::class, 'deactivate'])->name('admin.accountmanager.deactivate');

    // Admin Clients
    Route::get('client/add-client', [AdminClientController::class, 'index'])->name('admin.client.add-client');
    Route::post('admin-client-register', [AdminClientController::class, 'registerclient'])->name('admin.client.register');
    Route::get('client/edit-client/{id}', [AdminClientController::class, 'edit'])->name('admin.client.edit-client');
    Route::post('client/edit-client/{id}', [AdminClientController::class, 'update'])->name('admin.client.edit');
    Route::get('client/view-client/{id}', [AdminClientController::class, 'view'])->name('admin.client.view-client');
    Route::get('client/view-active-client', [AdminClientController::class, 'viewactiveclients'])->name('admin.client.view-active-client');
    Route::get('client/view-inactive-client', [AdminClientController::class, 'viewinactiveclients'])->name('admin.client.view-inactive-client');
    Route::get('client/delete-client/{id}', [AdminClientController::class, 'delete'])->name('admin.client.delete');
    Route::get('client/activate-client/{id}', [AdminClientController::class, 'activate'])->name('admin.client.activate');
    Route::get('client/deactivate-client/{id}', [AdminClientController::class, 'deactivate'])->name('admin.client.deactivate');

    // Admin Pipeline
    Route::get('pipeline/view-pipeline', [AdminPipelineController::class, 'index'])->name('admin.pipeline.view-pipeline');
    Route::get('pipeline/add-pipeline', [AdminPipelineController::class, 'addpipeline'])->name('admin.pipeline.add-pipeline');
    Route::post('admin-pipeline-create', [AdminPipelineController::class, 'createpipeline'])->name('admin.pipeline.create');
    Route::get('pipeline/edit-pipeline/{id}', [AdminPipelineController::class, 'edit'])->name('admin.pipeline.edit-pipeline');
    Route::post('pipeline/edit-pipeline/{id}', [AdminPipelineController::class, 'update'])->name('admin.pipeline.edit');
    Route::get('pipeline/delete-pipeline/{id}', [AdminPipelineController::class, 'delete'])->name('admin.pipeline.delete');
    Route::get('pipeline/detail-pipeline/{id}', [AdminPipelineController::class, 'detail'])->name('admin.pipeline.detail-pipeline');

    // Admin Sub Accounts
    Route::get('subaccount/add-sub-account', [AdminSubAccountController::class, 'index'])->name('admin.subaccount.add-sub-account');
    Route::post('admin-subaccount-register', [AdminSubAccountController::class, 'registersubaccount'])->name('admin.subaccount.register');
    Route::get('subaccount/edit-sub-account/{id}', [AdminSubAccountController::class, 'edit'])->name('admin.subaccount.edit-sub-account');
    Route::post('subaccount/edit-sub-account/{id}', [AdminSubAccountController::class, 'update'])->name('admin.subaccount.edit');
    Route::get('subaccount/view-sub-account/{id}', [AdminSubAccountController::class, 'view'])->name('admin.subaccount.view-sub-account');
    Route::get('subaccount/view-active-sub-account', [AdminSubAccountController::class, 'viewactive'])->name('admin.subaccount.view-active-sub-account');
    Route::get('subaccount/view-inactive-sub-account', [AdminSubAccountController::class, 'viewinactive'])->name('admin.subaccount.view-inactive-sub-account');
    Route::get('subaccount/activate-sub-account/{id}', [AdminSubAccountController::class, 'activate'])->name('admin.subaccount.activate');
    Route::get('subaccount/deactivate-sub-account/{id}', [AdminSubAccountController::class, 'deactivate'])->name('admin.subaccount.deactivate');
    Route::get('subaccount/delete-sub-account/{id}', [AdminSubAccountController::class, 'delete'])->name('admin.subaccount.delete');

    // Admin Groups
    Route::get('group/add-group', [AdminGroupController::class, 'index'])->name('admin.group.add-group');
    Route::post('admin-group-create', [AdminGroupController::class, 'creategroup'])->name('admin.group.create');
    Route::get('group/group-contact-list', [AdminGroupController::class, 'viewcontacts'])->name('admin.group.group-contact-list');
    Route::get('group/view-group', [AdminGroupController::class, 'view'])->name('admin.group.view-group');
    Route::get('group/edit-group/{id}', [AdminGroupController::class, 'edit'])->name('admin.group.edit-group');
    Route::post('group/edit-group/{id}', [AdminGroupController::class, 'update'])->name('admin.group.edit');
    Route::get('group/detail-group/{id}', [AdminGroupController::class, 'detail'])->name('admin.group.detail-group');
    Route::get('group/delete-group/{id}', [AdminGroupController::class, 'delete'])->name('admin.group.delete');

    // Admin Contacts
    Route::get('contact/add-contact', [AdminContactController::class, 'index'])->name('admin.contact.add-contact');
    Route::post('admin-contact-create', [AdminContactController::class, 'createcontact'])->name('admin.contact.create');
    Route::get('contact/view-contact', [AdminContactController::class, 'view'])->name('admin.contact.view-contact');
    Route::get('contact/edit-contact/{id}', [AdminContactController::class, 'edit'])->name('admin.contact.edit-contact');
    Route::post('contact/edit-contact/{id}', [AdminContactController::class, 'update'])->name('admin.contact.edit');
    Route::get('contact/detail-contact/{id}', [AdminContactController::class, 'detail'])->name('admin.contact.detail-contact');
    Route::get('contact/import-contact', [AdminContactController::class, 'importcontactview'])->name('admin.contact.import-contact');
    Route::get('contact/delete-contact/{id}', [AdminContactController::class, 'delete'])->name('admin.contact.delete');
    Route::get('contact/block-contact/{id}', [AdminContactController::class, 'block'])->name('admin.contact.block');

    // Admin Logs
    Route::get('logs/admin-logs', [AdminLogsController::class, 'adminlogs'])->name('admin.logs.admin-logs');
    Route::get('logs/account-manager-logs', [AdminLogsController::class, 'accountmanagerlogs'])->name('admin.logs.account-manager-logs');
    Route::get('logs/client-logs', [AdminLogsController::class, 'client'])->name('admin.logs.client-logs');
    Route::get('logs/sub-account-logs', [AdminLogsController::class, 'subaccountlogs'])->name('admin.logs.sub-account-logs');
    Route::get('logs/demo-account-logs', [AdminLogsController::class, 'demoaccountlogs'])->name('admin.logs.demo-account-logs');

    // Admin Blacklist
    Route::get('blacklist/view-client-blacklist', [AdminBlacklistController::class, 'clientsblacklist'])->name('admin.blacklist.view-client-blacklist');
    Route::get('blacklist/view-sub-account-blacklist', [AdminBlacklistController::class, 'subaccountsblacklist'])->name('admin.blacklist.view-sub-account-blacklist');
    Route::get('blacklist/detail-blacklist', [AdminBlacklistController::class, 'detail'])->name('admin.blacklist.detail-blacklist');

    // Admin Complains And Feedback
    Route::get('complaintsandfeedback/acc-manager-feedback', [AdminComplaintAndFeedbackController::class, 'accountmanagerfeedback'])->name('admin.complaintsandfeedback.acc-manager-feedback');
    Route::get('complaintsandfeedback/client-feedback', [AdminComplaintAndFeedbackController::class, 'clientfeedback'])->name('admin.complaintsandfeedback.client-feedback');
    Route::get('complaintsandfeedback/sub-account-feedback', [AdminComplaintAndFeedbackController::class, 'subaccountfeedback'])->name('admin.complaintsandfeedback.sub-account-feedback');
    Route::get('complaintsandfeedback/demo-account-feedback', [AdminComplaintAndFeedbackController::class, 'demoaccountfeedback'])->name('admin.complaintsandfeedback.demo-account-feedback');
    Route::get('complaintsandfeedback/detail-feedback', [AdminComplaintAndFeedbackController::class, 'detail'])->name('admin.complaintsandfeedback.detail-feedback');

});