<?php

use App\Http\Controllers\Client\ClientAuthController;
use App\Http\Controllers\Client\ClientBlacklistController;
use App\Http\Controllers\Client\ClientComplaintAndFeedbackController;
use App\Http\Controllers\Client\ClientContactController;
use App\Http\Controllers\Client\ClientDashboardController;
use App\Http\Controllers\Client\ClientGroupController;
use App\Http\Controllers\Client\ClientLogsController;
use App\Http\Controllers\Client\ClientProfileController;
use App\Http\Controllers\Client\ClientSmsController;
use App\Http\Controllers\Client\ClientSubAccountController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


// Client Login And Registration
Route::get('/', [ClientAuthController::class, 'index'])->name('client');
Route::post('custom-login', [ClientAuthController::class, 'customLogin'])->name('client.login.custom');
Route::get('signout', [ClientAuthController::class, 'signOut'])->name('client.signout');

Route::middleware(\App\Http\Middleware\ClientAuthMiddleware::class)->group(function(){

    // Client Dashboard
    Route::get('dashboard', [ClientDashboardController::class, 'index'])->name('client.dashboard');

    // Client Profile
    Route::get('profile', [ClientProfileController::class, 'index'])->name('client.profile');

    // Client SMS
    Route::get('sms/compose', [ClientSmsController::class, 'compose'])->name('client.sms.compose');
    Route::get('sms/sent-items', [ClientSmsController::class, 'sent_items'])->name('client.sms.sent-items');
    Route::get('sms/group-sms', [ClientSmsController::class, 'group_sms'])->name('client.sms.group-sms');
    Route::get('sms/schedule-sms', [ClientSmsController::class, 'schedule_sms'])->name('client.sms.schedule-sms');

    // Client Sub Accounts
    Route::get('subaccount/add-sub-account', [ClientSubAccountController::class, 'index'])->name('client.subaccount.add-sub-account');
    Route::post('client-subaccount-register', [ClientSubAccountController::class, 'registersubaccount'])->name('client.subaccount.register');
    Route::get('subaccount/edit-sub-account/{id}', [ClientSubAccountController::class, 'edit'])->name('client.subaccount.edit-sub-account');
    Route::post('subaccount/edit-sub-account/{id}', [ClientSubAccountController::class, 'update'])->name('client.subaccount.edit');
    Route::get('subaccount/view-sub-account/{id}', [ClientSubAccountController::class, 'view'])->name('client.subaccount.view-sub-account');
    Route::get('subaccount/view-active-sub-account', [ClientSubAccountController::class, 'viewactive'])->name('client.subaccount.view-active-sub-account');
    Route::get('subaccount/view-inactive-sub-account', [ClientSubAccountController::class, 'viewinactive'])->name('client.subaccount.view-inactive-sub-account');
    Route::get('subaccount/activate-sub-account/{id}', [ClientSubAccountController::class, 'activate'])->name('client.subaccount.activate');
    Route::get('subaccount/deactivate-sub-account/{id}', [ClientSubAccountController::class, 'deactivate'])->name('client.subaccount.deactivate');
    Route::get('subaccount/delete-sub-account/{id}', [ClientSubAccountController::class, 'delete'])->name('client.subaccount.delete');

    // Client Groups
    Route::get('group/add-group', [ClientGroupController::class, 'index'])->name('client.group.add-group');
    Route::post('client-group-create', [ClientGroupController::class, 'creategroup'])->name('client.group.create');
    Route::get('group/group-contact-list', [ClientGroupController::class, 'viewcontacts'])->name('client.group.group-contact-list');
    Route::get('group/view-group', [ClientGroupController::class, 'view'])->name('client.group.view-group');
    Route::get('group/edit-group/{id}', [ClientGroupController::class, 'edit'])->name('client.group.edit-group');
    Route::post('group/edit-group/{id}', [ClientGroupController::class, 'update'])->name('client.group.edit');
    Route::get('group/detail-group/{id}', [ClientGroupController::class, 'detail'])->name('client.group.detail-group');
    Route::get('group/delete-group/{id}', [ClientGroupController::class, 'delete'])->name('client.group.delete');

    // Client Contacts
    Route::get('contact/add-contact', [ClientContactController::class, 'index'])->name('client.contact.add-contact');
    Route::post('client-contact-create', [ClientContactController::class, 'createcontact'])->name('client.contact.create');
    Route::get('contact/view-contact', [ClientContactController::class, 'view'])->name('client.contact.view-contact');
    Route::get('contact/edit-contact/{id}', [ClientContactController::class, 'edit'])->name('client.contact.edit-contact');
    Route::post('contact/edit-contact/{id}', [ClientContactController::class, 'update'])->name('client.contact.edit');
    Route::get('contact/detail-contact/{id}', [ClientContactController::class, 'detail'])->name('client.contact.detail-contact');
    Route::get('contact/delete-contact/{id}', [ClientContactController::class, 'delete'])->name('client.contact.delete');
    Route::get('contact/block-contact/{id}', [ClientContactController::class, 'block'])->name('client.contact.block');
    Route::get('contact/import-contact', [ClientContactController::class, 'importcontactview'])->name('client.contact.import-contact');

    // Client Logs
    Route::get('logs/client-logs', [ClientLogsController::class, 'client'])->name('client.logs.client-logs');
    Route::get('logs/sub-account-logs', [ClientLogsController::class, 'subaccountlogs'])->name('client.logs.sub-account-logs');

    // Client Blacklist
    Route::get('blacklist/view-client-blacklist', [ClientBlacklistController::class, 'clientsblacklist'])->name('client.blacklist.view-client-blacklist');
    Route::get('blacklist/view-sub-account-blacklist', [ClientBlacklistController::class, 'subaccountsblacklist'])->name('client.blacklist.view-sub-account-blacklist');
    Route::get('blacklist/detail-blacklist', [ClientBlacklistController::class, 'detail'])->name('client.blacklist.detail-blacklist');

    // Client Complains And Feedback
    Route::get('complaintsandfeedback/client-feedback', [ClientComplaintAndFeedbackController::class, 'clientfeedback'])->name('client.complaintsandfeedback.client-feedback');
    Route::get('complaintsandfeedback/sub-account-feedback', [ClientComplaintAndFeedbackController::class, 'subaccountfeedback'])->name('client.complaintsandfeedback.sub-account-feedback');
    Route::get('complaintsandfeedback/detail-feedback', [ClientComplaintAndFeedbackController::class, 'detail'])->name('client.complaintsandfeedback.detail-feedback');
});